/* GNOME DB library
 * Copyright (C) 1999 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "gnome-db-shortcut.h"
#include "gnome-db-util.h"
#include <libgnome/gnome-i18n.h>

/*
 * Public functions
 */
static void
gnome_db_shortcut_realize (GnomeDbShortcut *shortcut)
{
	GtkObjectClass *parent_class;

	g_return_if_fail(GNOME_DB_IS_SHORTCUT(shortcut));

	parent_class = gtk_type_class (gtk_vbox_get_type ());
	if (GTK_WIDGET_CLASS (parent_class)->realize)
		GTK_WIDGET_CLASS (parent_class)->realize (GTK_WIDGET (shortcut));

	gnome_db_set_bg_color(GTK_WIDGET(shortcut), 1, 1, 1);
}

static void
gnome_db_shortcut_class_init (GnomeDbShortcutClass *klass)
{
	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

	widget_class->realize = gnome_db_shortcut_realize;
}

static void
gnome_db_shortcut_init (GnomeDbShortcut *shortcut)
{
	GtkWidget* frame;

	/* create the toolbar widget */
	frame = gnome_db_new_frame_widget (NULL);
	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
	gtk_box_pack_start (GTK_BOX (shortcut), frame, 1, 1, 0);
	shortcut->tb = gnome_db_new_toolbar_widget (GTK_ORIENTATION_VERTICAL,
						    GTK_TOOLBAR_BOTH,
						    NULL, NULL);
	gtk_toolbar_set_tooltips (GTK_TOOLBAR (shortcut->tb), FALSE);
	gtk_container_set_border_width (GTK_CONTAINER (shortcut->tb), 8);
	gtk_container_add (GTK_CONTAINER (frame), shortcut->tb);
}

GtkType
gnome_db_shortcut_get_type (void)
{
	static GtkType type = 0;

	if (!type) {
		GtkTypeInfo info = {
			"GnomeDbShortcut",
			sizeof (GnomeDbShortcut),
			sizeof (GnomeDbShortcutClass),
			(GtkClassInitFunc) gnome_db_shortcut_class_init,
			(GtkObjectInitFunc) gnome_db_shortcut_init,
			(GtkArgSetFunc) NULL,
			(GtkArgGetFunc) NULL
		};
		type = gtk_type_unique (gtk_vbox_get_type (), &info);
	}
	return (type);
}

GtkWidget *
gnome_db_shortcut_new (void)
{
	GnomeDbShortcut* shortcut;

	shortcut = GNOME_DB_SHORTCUT (gtk_type_new (gnome_db_shortcut_get_type ()));
	return GTK_WIDGET (shortcut);
}

void
gnome_db_shortcut_append (GnomeDbShortcut *shortcut,
                          const gchar *str,
                          const gchar *tooltip,
                          const gchar *icon_file,
                          GtkSignalFunc select_func,
                          gpointer user_data)
{
	GtkWidget* pixmap;

	g_return_if_fail(GNOME_DB_IS_SHORTCUT(shortcut));
	g_return_if_fail(str != NULL);

	pixmap = gnome_stock_new_with_icon(icon_file);
	gtk_widget_show(pixmap);
	gtk_toolbar_append_space (GTK_TOOLBAR(shortcut->tb));
	gtk_toolbar_append_item (GTK_TOOLBAR(shortcut->tb), _(str),
				 _(tooltip), NULL, pixmap, select_func, user_data);
}

void
gnome_db_shortcut_remove (GnomeDbShortcut *shortcut, const gchar *str)
{
}

